==> haskell-reducers-3.12.1-25-i686.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.1
id: reducers-3.12.1-9jTmYEjFOosI30Qzbf0mZf
key: reducers-3.12.1-9jTmYEjFOosI30Qzbf0mZf
license: BSD3
copyright: Copyright (C) 2008-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework
category: Data, Math, Numerical, Semigroups
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Generator
    Data.Semigroup.Reducer Data.Semigroup.Reducer.With
    Data.Semigroup.Instances Data.Semigroup.Union Data.Semigroup.Apply
    Data.Semigroup.Applicative Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Self
abi: 5ce859b09906df7c57b3c53cec7c1b3e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/reducers-3.12.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/reducers-3.12.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/reducers-3.12.1
hs-libraries: HSreducers-3.12.1-9jTmYEjFOosI30Qzbf0mZf
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    fingertree-0.1.1.0-C6YFXKIQXOA6HvmvFT5gT9
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    semigroupoids-5.1-mvlh42rhjC5vNXakyMT7n
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reducers-3.12.1-29-i686.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.1
id: reducers-3.12.1-F2q2a7vUofMJpiZmR81GDd
key: reducers-3.12.1-F2q2a7vUofMJpiZmR81GDd
license: BSD3
copyright: Copyright (C) 2008-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework
category: Data, Math, Numerical, Semigroups
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Generator
    Data.Semigroup.Reducer Data.Semigroup.Reducer.With
    Data.Semigroup.Instances Data.Semigroup.Union Data.Semigroup.Apply
    Data.Semigroup.Applicative Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Self
abi: 7fc933003753470fbbc0767585e20609
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/reducers-3.12.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/reducers-3.12.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/reducers-3.12.1
hs-libraries: HSreducers-3.12.1-F2q2a7vUofMJpiZmR81GDd
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    fingertree-0.1.1.0-C6YFXKIQXOA6HvmvFT5gT9
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    semigroupoids-5.1-DqvBTbrE9taJE9BSSdjW0y
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
